pub struct updateFlowOperatorPermissionsCall {
pub token: Address,
pub flowOperator: Address,
pub permissions: u8,
pub flowrateAllowance: I96,
}Expand description
Function with signature updateFlowOperatorPermissions(address,address,uint8,int96) and selector 0x30885591.
function updateFlowOperatorPermissions(address token, address flowOperator, uint8 permissions, int96 flowrateAllowance) external returns (bool);Fields
token: AddressflowOperator: Addresspermissions: u8flowrateAllowance: I96Trait Implementations
Sourceimpl Clone for updateFlowOperatorPermissionsCall
impl Clone for updateFlowOperatorPermissionsCall
Sourcefn clone(&self) -> updateFlowOperatorPermissionsCall
fn clone(&self) -> updateFlowOperatorPermissionsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for updateFlowOperatorPermissionsCall
impl SolCall for updateFlowOperatorPermissionsCall
Sourceconst SIGNATURE: &'static str = "updateFlowOperatorPermissions(address,address,uint8,int96)"
const SIGNATURE: &'static str = "updateFlowOperatorPermissions(address,address,uint8,int96)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Address, Uint<8>, Int<96>)
type Parameters<'a> = (Address, Address, Uint<8>, Int<96>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<updateFlowOperatorPermissionsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<updateFlowOperatorPermissionsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = updateFlowOperatorPermissionsReturn
type Return = updateFlowOperatorPermissionsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<updateFlowOperatorPermissionsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<updateFlowOperatorPermissionsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.